library(DESeq2)
library(limma)

### read and prepare data
setwd("G:\\tiergenomik\\AG_bioinf\\teaching\\Bachelor\\Data\\ExampleRNAseq")
D2 = read.csv("GSE269413_2_day_raw.counts.csv")
D5 = read.csv("GSE269413_5_day_raw_counts.csv")
X = cbind(D2[,2:7], D5[,2:7])
rownames(X) = D2$Geneid
group = as.factor(rep(c("infec", "infec", "infec", "mock", "mock", "mock"), 2))
times = as.factor(c(rep("2", 7), rep("5", 7)))
dds = DESeqDataSetFromMatrix(X, DataFrame(group), ~ group)

### principal component analysis (pca)
norm = counts(dds, normalized=TRUE)
pca0 = prcomp(t(norm))
pca = predict(pca0)
plot(pca[,1], pca[,2], col=as.numeric(group), pch=as.numeric(times))
identify(pca[,1], pca[,2])

### differential expression analysis with DESeq2
dds = DESeq(dds)
res = results(dds)
res = res[order(res$pvalue),]
head(res)

### differential expression analysis with limma
E = voom(X)$E
M = model.matrix(~ group)
fit = lmFit(E, M)
fit = eBayes(fit)
P = fit$p.value[,2]
pFDR = p.adjust(P, method="BY")
logFC = fit$coefficients[,2]
sum(P<0.05)
sum(pFDR<0.05)
topTable(fit)
